@@ -2,12 +2,19 @@
 from pathlib import Path
 from flask import Flask
 
+from importlib.resources import files
+
+# import app
 from app.views import depht, train, models, documentation
 from app import config
-
+from app import templates, static
+# from app import static, templates
 
 PKG = "depht_gui"
 
+# templates_module = import_module("templates")
+# static_module = import_module("static")
+
 
 def create_app(name=PKG, **kwargs):
     """
@@ -16,8 +23,8 @@ def create_app(name=PKG, **kwargs):
     :param name: name of the app
     :type name: str
     """
-    app = Flask(name, template_folder="app/templates",
-                static_folder="app/static")
+    app = Flask(name, template_folder=files(templates),
+                static_folder=files(static))
 
     # app = Flask(name)
     app.config.from_object(config)
